#######################
#######################
#Main replication file#
#######################
#######################
#Authors: Gareth Nellis, Michael Weaver, Steven Rosenzweig
#Paper: Do parties matter for ethnic violence? Evidence from India
#Date: April 30, 2016

##############
#Instructions#
##############
#You must run this file from here until line 137
#before running code for any specific table.
#This code will set the working directory, generate output files,
#load packages and functions, set the seed, specify variables names and
#labels, and set parameters for formatting tables and figures.

#######################
#Set working directory#
#######################
#Insert path to "Replication File" folder
setwd("path/to/nwr_qjps_replication")

#Set to TRUE or FALSE
installPackages = FALSE

#Create folders to hold output generated by this replication code.
if (!dir.exists("./output")){
  dir.create("./output")
  dir.create("./output/figures")
  dir.create("./output/tables")
  dir.create("./output/simulations")
}

#Install packages: this will run on loop until all packages are installed.
if (installPackages) {
  source('./scripts/installPackages.R')
}

#######################################
#Do you want to make the latex tables?#
#######################################
make.latex.tables = TRUE

#Are you on a mac?
on.osx = FALSE

if (make.latex.tables & on.osx){
  x11()
  Sys.setenv(PATH=paste(Sys.getenv("PATH"),"/usr/texbin",sep=":"))
}


#########################
#Load packages/functions#
#########################
#download and locally load these packages
require(plm)
require(lfe)
require(plyr)
require(AER)
require(Hmisc)
require(MASS)
require(lattice)
require(latticeExtra)
require(gridExtra)
require(ggplot2)
require(data.table)
require(sandwich)
require(beanplot)
require(foreach)
require(doParallel)
require(tables)

#Clustered standard errors
source("scripts/functions/cluster2.R")
#Bootstrap clustered standard errors
source("scripts/functions/bs.cluster.R")
#Calculate confidence intervals
source("scripts/functions/ci.R")
#Local linear RD functions from Green, et al, Political Analysis (2009)
source("scripts/functions/Green_et_al_polanalysis_2009_edge.R")
source("scripts/functions/Green_et_al_polanalysis_2009_optimal_bw.R")
#Dotplot
source("scripts/functions/mydotplot.R")


##########
#Set seed#
##########
seed = 1461175338

######################
#Prepare for analysis#
######################

#You must run this code to set variable names as well as table and graph parameters.

#Variable Names
###############

#Count dependent variables
riot.dvs <- c("COUNT", "CASUALTIES", "RIOTDAYS")

#Long names for count DVs
riot.dv.names <- c("Riot Count", "Riot Casualties", "Days of Rioting")

#Logged dependent variables
log.riot.dvs <- paste('log.',riot.dvs, sep='')

log.riot.dvs <- c(log.riot.dvs, "COUNT.bin")

riot.dvs <- c(riot.dvs, "COUNT.bin")

#Long name for logged DVs
log.riot.dv.names <- c(paste('Log',riot.dv.names, sep=' '), "Pr(Any Riot)")
riot.dv.names <- c(riot.dv.names, "Any Riot")

#Table Features
###############

#Digits reported
digs <- 2

#Plot Features
##############
my.theme <- trellis.par.get()
my.theme$strip.background$col <- "gray90"
my.theme$plot.symbol$col <- "black"
my.theme$plot.line$col <- "black"
my.theme$plot.line$lwd <- 2
my.theme$axis.components$top$tck <- 0
my.theme$axis.components$right$tck <- 0

#List objects to keep
clean.workspace = c(ls(), "clean.workspace")

#################
#################
##Main analyses##
#################
#################

##########
#Figure 1#
##########

source('./scripts/Figure1.R')

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

##########
#Figure 2#
##########

source('./scripts/Figure2.R')

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

##########
#Figure 3#
##########

source('./scripts/Figure3.R')

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

##########
#Figure 4#
##########

source('./scripts/Figure4.R')

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

#########
#Table 1#
#########

source("./scripts/Table1.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

##############################
##############################
##Appendix A: Identification##
##############################
##############################

##########
#Table A1#
##########

source("./scripts/TableA1.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

##########
#Table A2#
##########

source("./scripts/TableA2.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

################
#Figures A2, A3#
################

source("./scripts/FigureA2_A3.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

###############
#Figure A4, A7#
###############

source("./scripts/FigureA4_A7.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

###############
#Figure A5, A6#
###############

source("./scripts/FigureA5_A6.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

####################################
####################################
##Appendix D: Supplemental Results##
####################################
####################################

##########
#Table D1#
##########

source("./scripts/TableD1.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

##########
#Table D2#
##########

source("./scripts/TableD2.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

##########
#Table D3#
##########

source("./scripts/TableD3.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

###########
#Figure D1#
###########

source("./scripts/FigureD1.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

###########
#Figure D2#
###########

source("./scripts/FigureD2.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

###########
#Figure D3#
###########

source("./scripts/FigureD3.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

###########
#Figure D4#
###########

source("./scripts/FigureD4.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

###########
#Figure D5#
###########

source("./scripts/FigureD5.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

###########
#Figure D6#
###########

source("./scripts/FigureD6.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

###########
#Figure D7#
###########

source("./scripts/FigureD7.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

###############
#Figure D8, D9#
###############

source("./scripts/FigureD8_D9.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

############
#Figure D10#
############

#This will take a very long time to run 
#(several hours using a late-model laptop with 8GB of RAM)
#Using more powerful hardware helps substantially.
#Set the number of cores you would like to use for parallel processing
number.of.cores = 2
source("./scripts/FigureD10.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

############
#Figure D11#
############

source("./scripts/FigureD11.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

############
#Figure D12#
############

source("./scripts/FigureD12.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

############
#Figure D13#
############

source("./scripts/FigureD13.R")

#Clean workspace
rm(list = setdiff(ls(), clean.workspace) )

