############
############
##Figure 3##
############
############

#######################################
#Difference in means###################
#For districts with one close election#
#######################################

#Load data for 1 percent bandwidth
data <- read.csv("./data/analysisPanelBW1.csv", as.is=T)

#Restrict to data with 1 close election
data.one <- data[round(data$rd_INC_closenum)==1,]

#Create plot data for Figure 3
diff.mean.data = data.frame(matrix(NA, nrow=length(log.riot.dvs)*3, ncol=6))
diff.mean.data[,1] = rep(gsub("Log ", "", log.riot.dv.names), each=3)
diff.mean.data[,2] = rep(3:1, length(log.riot.dvs))
names(diff.mean.data) = c("DV", "type", "mean", "lower", "upper", 'p')

#Set treatment variable
IV_exo = "rd_INC_ivnum"

#Use regression so that we can get clustered standard errors
#Regress all logged riot DVs on congress win in close election
out <- Map(function(y,x) lm(as.formula(paste(y,"~",x)),data=data.one),log.riot.dvs,IV_exo)

#Obtain clustered standard errors for each model
for (i in 1:length(out)){
  est = out[[i]]
  est.cl = coeftest.cluster(data.one, est, cluster1="DISTRICT_ID_61", vcov=T)
  
  #Obtain standard errors for treatment, control, and difference 
  #transformed to original scale (unlogged)
  sims = mvrnorm(1000, mu = est$coef, Sigma = est.cl[[2]], empirical=T)
  if (i %in% 1:3){
    c = mean(exp(sims[,1]))
    t = mean(exp(sims[,1] + sims[,2]))
    diff = mean(exp(sims[,1] + sims[,2]) - exp(sims[,1]))
    
    c.se = quantile(exp(sims[,1]), c(.025,.975))
    t.se = quantile(exp(sims[,1] + sims[,2]), c(.025,.975))
    diff.se = quantile(exp(sims[,1] + sims[,2]) - exp(sims[,1]), c(.025,.975))
  } else {
    c = mean(sims[,1])
    t = mean(sims[,1] + sims[,2])
    diff = mean(sims[,2])
    
    c.se = quantile((sims[,1]), c(.025,.975))
    t.se = quantile((sims[,1] + sims[,2]), c(.025,.975))
    diff.se = quantile((sims[,1] + sims[,2]) - (sims[,1]), c(.025,.975))
  }
  
  p = est.cl[[1]][2,4]
  
  #Save estimates for plotting
  diff.mean.data[(1+(i-1)*3):(i*3),3:6] = cbind(c(c,t,diff), rbind(c.se,t.se,diff.se), rep(p, 3))
}

data.for.plots = diff.mean.data

###################
#Generate Figure 3#
###################

#Plot labels
y.scale <- list(y=list(at=3:1, labels=c("Control", "Treated", "Difference"), alternating=F))
y.label <- "Group"
x.label <- "Mean"
y.limits <- c(.5,3.5)

#Size on page
width <- 6
height <- 6

#plot parameters
diff.mean.theme = my.theme
diff.mean.theme$superpose.line = list(col=c(gray(.7), gray(.7),1), lwd=2)

#Separate plot data
plot.temp.1 = data.for.plots[data.for.plots$DV!="Pr(Any Riot)",]
plot.temp.2 = data.for.plots[data.for.plots$DV=="Pr(Any Riot)",]

#File preparation
name <- "Figure3"
file.name <- paste("./output/figures/",name,".pdf", sep="")

pdf(file.name, width=width, height=height)

x.limits.1 <- max(abs(plot.temp.1[,4:5])) * c(-1.05, 1.05)
dot.plot.1 <- Dotplot(type ~ Cbind(mean, lower, upper) | DV, groups=rep(3:1,3), data=plot.temp.1, strip.blank=T, col=c(1,gray(.7), gray(.7)), pch=c(19,8,8),layout=c(1,3), par.settings= diff.mean.theme, cex=1.1, scales=y.scale, ylab=y.label, xlab=x.label, xlim=x.limits.1, ylim=y.limits,
                      panel = function(...){
                        panel.abline(v=0, lty=2, col="gray50")
                        panel.myDotplot(...)
                      })

x.limits.2 <- max(abs(plot.temp.2[,4:5])) * c(-1.05, 1.05)	
dot.plot.2 <- Dotplot(type ~ Cbind(mean, lower, upper) | DV, groups=3:1, data=plot.temp.2, strip.blank=T, col=c(1,gray(.7), gray(.7)), pch=c(19,8,8), par.settings= diff.mean.theme, cex=1.1, scale = y.scale, ylab=NULL, xlab=NULL, xlim=x.limits.2, ylim=y.limits,
                      panel = function(...){
                        panel.abline(v=0, lty=2, col="gray50")
                        panel.myDotplot(...)
                      })	

dot.plot = c(dot.plot.2, dot.plot.1, layout=c(1,4))	

dot.plot = update(dot.plot, between=list(y=c(0,-1.8,-1.8)), scales=list(x=list(at=list(NA, NA, NULL, NULL))), xlab= x.label, ylab=y.label)

print(dot.plot)
dev.off()

#Print table used for chart
cat("\n")
print("Figure 3")
print(data.for.plots)
cat('\n')

#Wilcox test, as reported in footnote (?)
print('Wilcox test, as reported in footnote (?)')
#Non-parametric test of whether distributions of riot count, casualties, and days 
#are shifted to the left when Congress wins a close election (i.e. fewer riots)
#Count
wilcox.test(data.one$COUNT[data.one$rd_INC_ivnum>0], data.one$COUNT[data.one$rd_INC_ivnum==0], paired=F, alternative = 'l')

#Casualties
wilcox.test(data.one$CASUALTIES[data.one$rd_INC_ivnum>0], data.one$CASUALTIES[data.one$rd_INC_ivnum==0], paired=F, alternative = 'l')

#Riot days
wilcox.test(data.one$RIOTDAYS[data.one$rd_INC_ivnum>0], data.one$RIOTDAYS[data.one$rd_INC_ivnum==0], paired=F, alternative = 'l')