###################
###################
##FIGURE A2 & A3###
###################
###################

###########
#Load data#
###########

elections = read.csv("./data/closeElectionBalanceData.csv", as.is=T)

######################################
#Define balance covariates and labels#
######################################

#Election characteristics
dvs = c("seat.sc", "seat.st", "women", "ENP", "total_votes", "turnout", "invalid", "invalid.na", "registered_voters", 'pop', 'pct_muslim', 'pct_urban', 'pop_density', 'INC_org', 'INC_org_3')

dv.names = c("SC Seat", "ST Seat", "% Women Candidates", "ENP", "Total Votes", "% Turnout", "Invalid Votes", "Invalid Missing", "Electors", 'Population', '% Muslim', "% Urban", 'Population Density', 'INC Organization', 'INC Organization (High)')

#Treatment variable
x = c("rd_INC_win")


##########################
#Figure A2################
##########################
#Difference in means test#
##########################
#Compares means in elections where Congress wins/loses within 1% bandwidth

#Create table to hold test results
balance.plot.data <- data.frame(matrix(NA, nrow=3*length(dvs), ncol=7))
names(balance.plot.data) <- c("DV", "BW", "Beta", "lower", "upper", "p", 'N')
balance.plot.data$DV <- rep(dv.names, 3)
balance.plot.data$BW <- rep(1:3, each=length(dvs))

#Loop over bandwidths
for (bw in 1:3){
  #Select elections within bandwidth
  temp.subset = elections[which(abs(elections$rd_INC_mov)<=bw),]

  #Scale each covariate so they are on comparable scale
  for (dv in dvs){
    temp.subset[,dv] = scale(temp.subset[,dv])
  }
  
  #Estimate difference in means
  out <- Map(function(y,x) lm(as.formula(paste(y,"~",x)),data=temp.subset),dvs,x)
  
  #Calculate robust or clustered standard errors
  for (j in 1:length(dvs)){
    est <- out[[j]]
    #These are measured at a district level, and so we use clustering at district level
    district_var = dvs[j] %in% c('pop', 'pct_muslim', 'pct_urban', 'pop_density', 'INC_Org', 'INC_Org_3')
    if (!district_var) {
      #If not a district variable, robust standard errors
      est.cl <- coeftest(est, vcov=vcovHC(est, type="HC3"))
    }
    if (district_var){
      #If a district variable, clustered errors
      est.cl <- coeftest.cluster(temp.subset, est, cluster1="DISTRICT_ID_61")
    }
    #Extract relevant parameters
    coef <- est.cl[2,1]
    se <- est.cl[2,2]
    upper <- coef + 1.96*se
    lower <- coef - 1.96*se
    p <- est.cl[2,4]
    N <- length(est$residuals)
    #Write to plot data
    balance.plot.data[j + length(out) * (bw-1),3:7] <- c(coef, lower, upper, p, N)
  }
}

#######################
#Generate p-value plot#
#######################
width = 6
height = 6

y.label <- "Election Characteristics"
x.label <- "p-value"
y.limits <- range((0:length(dvs)) + .5)
x.limits <- c(0,1)

file.name.p = "./output/figures/FigureA2-p.pdf"

pdf(file.name.p, width=width, height=height)
dot.plot <- Dotplot(as.factor(DV) ~ p, data=balance.plot.data[balance.plot.data$BW==1,], 
                    strip.blank=T, col=1,  par.settings=my.theme, cex=1.1, ylab=y.label, 
                    xlab=x.label, xlim=x.limits, ylim=y.limits,
                    panel = function(...){
                      panel.Dotplot(...)
                      panel.abline(v=0.05, lty=2, col="gray50")})
print(dot.plot)	
dev.off()


####################
#Generate Figure A2#
####################

x.limits <- max(abs(balance.plot.data[,c('lower','upper')])) * c(-1.05,1.05)
x.label <- "Differences (Normalized)"

file.name = "./output/figures/FigureA2.pdf"

pdf(file.name, width=width, height=height)
dot.plot <- Dotplot(as.factor(paste(DV, " (",N,")", sep = "")) ~ Cbind(Beta, lower, upper), 
                    data=balance.plot.data[balance.plot.data$BW==1,], strip.blank=T, col=1,  
                    par.settings=my.theme, cex=1.1, ylab=y.label, xlab=x.label, xlim=x.limits, 
                    ylim=y.limits,
                    panel = function(...){
                      panel.Dotplot(...)
                      panel.abline(v=0, lty=2, col="gray50")
                    })
print(dot.plot)	
dev.off()

#Print table used for chart
cat("\n")
print("Figure A2")
print(balance.plot.data[balance.plot.data$BW==1,])
cat('\n')

#########################
#Figure A3###############
#########################
#Local linear RD#########
#########################

#Select data where forcing variable is not missing
subset = elections[!is.na(elections$rd_INC_mov),]

#Create table to hold results
ll.rd.plot.data = as.data.frame(matrix(NA, nrow=length(dvs), ncol=7))
names(ll.rd.plot.data) = c(
  "DV", "BW", "Beta", "lower", "upper", "p", 'N')
ll.rd.plot.data$DV = dv.names

#Loop over covariates
for (j in 1:length(dvs)){
  #Select subset of the data where covariates are not missing
  temp.subset = subset[!is.na(subset[,dvs[j]]) & is.finite(subset[,dvs[j]]),]
  #Calculate optimal bandwidth using scaled covariate
  hhat.opt <- optimal.bw(Y = scale(temp.subset[,dvs[j]]), X = temp.subset$rd_INC_mov, c=0, reg=T)
  #Identify variables measured at district level
  district_var = dvs[j] %in% c('pop', 'pct_muslim', 'pct_urban', 'pop_density', 'INC_org', 'INC_org_3')
  if (!district_var) {
    #Estimate difference at the cutoff using local linear RD
    out.opt <- edge(Y = scale(temp.subset[,dvs[j]]), temp.subset$rd_INC_mov, c=0, h=hhat.opt)
  }
  if (district_var){
    #Estimate difference at the cutoff using local linear RD with clustered standard errors
    out.opt <- edge.cluster(Y = scale(temp.subset[,dvs[j]]), temp.subset$rd_INC_mov, c=0, h=hhat.opt, cluster=temp.subset$DISTRICT_ID_61)
  }
  
  #Parameter estimates
  coef <- out.opt$theta
  se <- out.opt$se
  upper <- coef + 1.96*se
  lower <- coef - 1.96*se
  t <- coef/se
  p = 2*pt(abs(t), df=out.opt$df, lower.tail=F)
  N = out.opt$N.unweighted
  ll.rd.plot.data[j,2:7] <- c(hhat.opt, coef, lower, upper, p, N)
}

#######################
#Generate p-value plot#
#######################
width = 6
height = 6

y.label <- "Election Characteristics"
x.label <- "p-value"
y.limits <- range((0:length(dvs)) + .5)
x.limits <- c(0,1)

file.name.p = "./output/figures/FigureA3-p.pdf"

pdf(file.name.p, width=width, height=height)		
dot.plot <- Dotplot(as.factor(DV) ~ p, data= ll.rd.plot.data, strip.blank=T, col=1,  
                    par.settings=my.theme, cex=1.1, ylab=y.label, xlab=x.label, xlim=x.limits, 
                    ylim=y.limits,
                    panel = function(...){
                      panel.Dotplot(...)
                      panel.abline(v=0.05, lty=2, col="gray50")})
print(dot.plot)
dev.off()

####################
#Generate Figure A3#
####################

x.limits <- max(abs(ll.rd.plot.data[,c('lower','upper')])) * c(-1.05,1.05)
x.label <- "Differences (Normalized)"

file.name = "./output/figures/FigureA3.pdf"
pdf(file.name, width=width, height=height)
dot.plot <- Dotplot(as.factor(paste(DV, " (",N,")", sep = "")) ~ Cbind(Beta, lower, upper), data=ll.rd.plot.data, strip.blank=T, col=1,  par.settings=my.theme, cex=1.1, ylab=y.label, xlab=x.label, xlim=x.limits, ylim=y.limits,
                    panel = function(...){
                      panel.Dotplot(...)
                      panel.abline(v=0, lty=2, col="gray50")
                    })
print(dot.plot)
dev.off()

#Print table used for chart
cat("\n")
print("Figure A3")
print(ll.rd.plot.data)
cat('\n')


