#############
#############
#FIGURE D10##
#############
#############

#Set seed
set.seed(seed)


#####################################
#Have simulations already been done?#
#####################################

if (!file.exists("./output/simulations/FigureD10.csv")){

###########
#Load data#
###########
file.path <- paste("./data/analysisPanelBW1.csv", sep="")
data <- read.csv(file.path)


#########################################
#Estimate Reduced Form Negative Binomial#
#########################################

#To change outcome, change COUNT to CASUALTIES or RIOTDAYS
#Estimate model
model <- suppressWarnings(glm.nb(COUNT ~ rd_INC_iv + saturated, data=data))

#############
#Simulations#
#############

cluster.var = "DISTRICT_ID_61"
closenum.var = 'rd_INC_closenum'
seatnum.var = 'seatnum'
#Bootstrap simulations
k = 1000
#Montecarlo simulations (for varying rates of INC victory in close election)
sims = 250
#INC victory probabilities
INC.prob = seq(0, 1 , 0.2)
alpha=.05
cores = number.of.cores
                           
#Obtain estimator attributes
call <- as.character(model$call)
terms <- as.character(model$terms)
estimator <- call[1]

if (estimator == 'ivreg'){formula <- paste(terms[1], gsub("~", "|",terms[2]))} else {formula <- paste(terms[2],terms[1],terms[3],sep=" ")}
use.data <- call[3]
varlist <- names(model$model)

#Select relevant data columns
temp.data <- subset(get(use.data), select=c(varlist,cluster.var,seatnum.var,closenum.var))

#Identify clusters
clusters <- unique(temp.data[,cluster.var])

#Identify rows associated with each cluster
cl.index <- vector('list', length(clusters))
names(cl.index) <- clusters

for (j in 1:length(clusters)){
  cl.index[[j]] <- which(temp.data[,cluster.var]==clusters[j])
}

#Prepare parallel processing
cl <- makeCluster(cores)
registerDoParallel(cl)

#Bootstrap in parallel
results <- foreach(i = 1:k , .errorhandling = 'remove', .packages=c('data.table','MASS')) %dopar% {
  #Create clustered bootstrap data
  cluster.sample <- sample(clusters, replace=T)
  bs.sample.index <- unlist(cl.index[c(as.character(cluster.sample))])
  bs.data <- as.data.table(temp.data[bs.sample.index,])
  
  #Estimate model
  #Try, as some models may fail to converge during resampling
  try(suppressWarnings(est <- glm.nb(as.formula(formula), data = bs.data) ))
  
  #If model converges, obtain estimated differences
  #if (exists('est')){
  #Model matrix 
  model.mat <- as.data.table(model.matrix(COUNT ~ rd_INC_iv + saturated, data=bs.data))[, .SD, .SDcols = names(est$coef)]
  
  #Predict riots for actual, lose, win
  riots.actual = sum(predict(est, bs.data, type = "response"))
  
  #Predict riots for varying rates of INC victory
  riots.varying = vector(mode = 'list', length = length(INC.prob))
  
  #Expand bootstrap data for montecarlo simulation
  bs.data.p = do.call("rbind", replicate(sims, bs.data, simplify = FALSE))
  bs.data.p[, sim := rep(1:sims, each = nrow(bs.data))]
  
  #Expand model matrix for montecarlo simulation
  model.mat.p = do.call("rbind", replicate(sims, model.mat, simplify = FALSE))
  
  #Loop over INC probability of victory
  for (q in 1:length(INC.prob)){
    p = INC.prob[q]
    print(p)
    
    p.win.count = rbinom(nrow(bs.data.p), bs.data.p[, rd_INC_closenum], prob = p)
    p.win.pct = p.win.count/ bs.data.p[, seatnum]
    model.mat.p[, rd_INC_iv := p.win.pct]

    y.hat = exp(as.matrix(model.mat.p) %*% est$coef)
    bs.data.p[, riot.hat := y.hat]
    
    riots.varying[[q]] = bs.data.p[, list(riots.p = sum(riot.hat)), by = sim][, p := p][, list(p, riots.p)]
  }
  
  #Calculate estimated difference
  out = do.call('rbind', riots.varying)
  out[, riots.p := riots.p - riots.actual]
  return(out)
  #}
  
}
stopCluster(cl = cl)
stopImplicitCluster()

plot.data = do.call('rbind', results)

write.csv(plot.data, "./output/simulations/FigureD10.csv", row.names = F)
}

plot.data = fread('./output/simulations/FigureD10.csv')

pdf("./output/figures/FigureD10.pdf", height = 5, width = 6.5)
beanplot(riots.p ~ p, data = plot.data, what = c(0,1,1,0), 
         beanlines = "median", bw = 1, 
         col = c('gray70', 'black', 'black', 'gray60'),
         border = NA, method = "jitter",
         xlab = "Pr(INC victory) in close elections",
         ylab = "Predicted change in riots")

abline(h=0, lty = 2)
  
ci.text = plot.data[, list(median = median(riots.p), 
                           l.95 = quantile(riots.p, probs = 0.025), 
                           u.95 = quantile(riots.p, probs= 0.975),
                           p_0 = sum(riots.p * sign(median(riots.p)) < 0) / length(riots.p) ), by = p]

text(1:nrow(ci.text), ci.text[,median], round(ci.text[,median]))

dev.off()

#Print data for the plot
#Print table used for chart
cat("\n")
print("Figure D10")
print(ci.text)
cat('\n')


