#############
#############
##FIGURE D4##
#############
#############

###########
#Load data#
###########

#1% bandwidth
file.path <- paste("./data/analysisPanelBW1.csv", sep="")
temp <- read.csv(file.path)


#Make district factor
temp$district = as.factor(temp$DISTRICT_ID_61)

#Create year dummies for each district-election cycle
#Since states have different election cycles,
#we have to create year dummies for each year 
#included in an election cycle.
temp$last_year = c(temp$election_year[-1], NA)
temp$last_year[temp$last_year < temp$election_year] = NA
temp$last_year[is.na(temp$last_year)] = 2000

#Create dummies for each year
for (year in 1962:2000) {
  new_var = paste0('year',year)
  gt = year >= temp$election_year 
  lt = year < temp$last_year
  temp[,new_var] = 1 * (gt & lt)
}


########################
#District fixed effects#
########################

#Set variable names for analysis
################################

#Endogenous treatment variable
IV_end <- "rd_INC_seatprop"
#Exogenous treatment variable
IV_exo <- "rd_INC_iv"
#Covariates
Cov <- paste(c('1'), collapse = "+")
#Fixed effects
FEs <- paste(c("saturated", "district"), collapse="+")
#Clustering variable
cluster <- paste(c("district"), collapse = "+")


#Create table for plot data
###########################
district.fe.plot.data <- data.frame(matrix(NA, nrow=length(log.riot.dvs), ncol=6))
names(district.fe.plot.data) <- c("DV", "BW", "Beta", "lower", "upper", "N")
district.fe.plot.data$DV <- log.riot.dv.names
district.fe.plot.data$BW <- rep(1, each=length(log.riot.dvs))


#Estimate IVLS with district fixed effects
###########################################
out = Map(function(y,w,fe,x,z,cl) felm(as.formula(paste(y,"~", w,"|",fe,"| (",x,"~",z,") |", cl)),data=temp),log.riot.dvs,Cov,FEs,IV_end,IV_exo,cluster)

#Save parameter estimates for plotting
for (m in 1:length(out)){
  est = out[[m]]
  coefs = summary(est)$coefficients
  match = grep(IV_end, rownames(coefs), fixed=T)
  beta = coefs[match,1]
  se = coefs[match,2]
  upper = beta + 1.96 * se
  lower = beta - 1.96 * se
  N = length(est$residuals)
  district.fe.plot.data[m,3:6] = c(beta, lower, upper, N)
}

####################
#Year fixed effects#
####################

#Set variable names for analysis
################################

#Endogenous treatment variable
IV_end <- "rd_INC_seatprop"
#Exogenous treatment variable
IV_exo <- "rd_INC_iv"
#Covariates
Cov <- paste(c(paste('year',1962:2000,sep = "")), collapse = "+")
#Fixed effects
FEs <- paste(c("saturated"), collapse="+")
#Clustering variable
cluster <- paste(c("district"), collapse = "+")

#Create table for plot data
###########################
year.fe.plot.data <- data.frame(matrix(NA, nrow=length(log.riot.dvs), ncol=6))
names(year.fe.plot.data) <- c("DV", "BW", "Beta", "lower", "upper", "N")
year.fe.plot.data$DV <- log.riot.dv.names
year.fe.plot.data$BW <- rep(1, each=length(log.riot.dvs))

#Estimate IVLS with year fixed effects
######################################
out = Map(function(y,w,fe,x,z,cl) felm(as.formula(paste(y,"~", w,"|",fe,"| (",x,"~",z,") |", cl)),data=temp),log.riot.dvs,Cov,FEs,IV_end,IV_exo,cluster)

#Save parameter estimates for plotting
for (m in 1:length(out)){
  est = out[[m]]
  coefs = summary(est)$coefficients
  match = grep(IV_end, rownames(coefs), fixed=T)
  beta = coefs[match,1]
  se = coefs[match,2]
  upper = beta + 1.96 * se
  lower = beta - 1.96 * se
  N = length(est$residuals)
  year.fe.plot.data[m,3:6] = c(beta, lower, upper, N)
}

#Warnings occur since some year dummies drop out


####################
#Generate Figure D4#
####################

district.fe.plot.data$type = 2
year.fe.plot.data$type = 1

#Combine data for plots
data.for.plots <- rbind(district.fe.plot.data,
                        year.fe.plot.data)

#Plot labels
y.scale <- list(y=list(at=2:1, labels=c("District FEs", "Year FEs"), alternating=F))
y.label <- "Model Specification"
x.label <- expression(paste(hat(beta),": Effect of Congress Seatshare"))
y.limits <- c(.5,2.5)

#Size on page
width <- 6
height <- 6

#Separate out for different scales
plot.temp.1 = data.for.plots[data.for.plots$DV!="Pr(Any Riot)",]
plot.temp.2 = data.for.plots[data.for.plots$DV=="Pr(Any Riot)",]

#File name
name <- "FigureD4"
file.name <- paste("./output/figures/",name,".pdf", sep="")

#Plot to pdf
pdf(file.name, width=width, height=height)
x.limits.1 <- max(abs(plot.temp.1[,4:5])) * c(-1.05, 1.05)

dot.plot.1 <- Dotplot(type ~ Cbind(Beta, lower, upper) | DV, data=plot.temp.1, strip.blank=T, col=1, layout = c(1,3), par.settings=my.theme, cex=1.1, scale = y.scale, ylab=NULL, xlab=NULL, xlim=x.limits.1, ylim=y.limits,
                      panel = function(...){
                        panel.Dotplot(...)
                        panel.abline(v=0, lty=2, col="gray50")})

x.limits.2 <- max(abs(plot.temp.2[,4:5])) * c(-1.05, 1.05)

dot.plot.2 <- Dotplot(type ~ Cbind(Beta, lower, upper) | DV, data=plot.temp.2, strip.blank=T, col=1, par.settings=my.theme, cex=1.1, scale = y.scale, ylab=NULL, xlab=NULL, xlim=x.limits.2, ylim=y.limits,
                      panel = function(...){
                        panel.Dotplot(...)
                        panel.abline(v=0, lty=2, col="gray50")})	

dot.plot = c(dot.plot.2, dot.plot.1, layout=c(1,4))	
dot.plot = update(dot.plot, between=list(y=c(0,-1.8,-1.8)), scales=list(x=list(at=list(NA, NA, NULL, NULL))), xlab= x.label, ylab=y.label)
print(dot.plot)
dev.off()

#Print table used for chart
cat("\n")
print("Figure D4")
print(data.for.plots)
cat('\n')