##################################
##################################
#Table 1#
##################################
##################################

###########
#Load data#
###########
data <- read.csv("./data/analysisPanelBW1.csv", as.is=T)

data$DISTRICT_ID_61 = as.factor(data$DISTRICT_ID_61)

##################
#Data preparation#
##################

#Datasets for fixed effects
###########################
#Select cases with no missing data on riots in the past year, no missing INC voteshare
temp.fe <- subset(data,  !is.na(COUNT_1yr) & !is.na(INC_voteshare) & !is.na(INC_voteshare_1ec))
temp.fe$election <- as.factor(temp.fe$election_year)

#Datasets for lagged dv
#######################
#Select cases with no missing data on riots in the past year, no missing INC voteshare
temp.ldv <- subset(data, !is.na(COUNT_1yr)  & !is.na(INC_voteshare) & !is.na(INC_voteshare_1ec))
temp.ldv$election <- as.factor(temp.ldv$election_year)


##########
#ANALYSIS#
##########


###############
#Fixed Effects#
###############

#Set dependent variables
DVs <- c("INC_voteshare", "BJP_voteshare", "INC_voteshare") 

#Lagged riot count (1 year)
iv <- c("COUNT_1yr", "COUNT_1yr", "COUNT_1yr")

#Lagged riot count (entire previous election cycle)
#iv <- c("COUNT_1ec", "COUNT_1ec", "COUNT_1ec")


#District and Year fixed effects
fe.s <-paste(c("election", "DISTRICT_ID_61"), collapse=" + ")

#Estimate models for different dependent variables
out.fe.1 <- Map(function(y,x,w) lm(as.formula(paste(y,"~",paste(x,w,sep="+"))),data=temp.fe),DVs,iv,fe.s)

#District and Year Fixed Effects. State time trends
fe.s <- paste(c("election", "DISTRICT_ID_61", paste(sort(unique(data$STATE)),"trend",sep="", collapse=" + ")), collapse=" + ")

#Estimate models for different dependent variables
out.fe.2 <- Map(function(y,x,w) lm(as.formula(paste(y,"~",paste(x,w,sep="+"))),data=temp.fe),DVs,iv,fe.s)


###########
#Lagged DV#
###########
#Year fixed effects and LDV
fe.s <-paste(c("election"), collapse=" + ")

out.ldv.1 <- Map(function(y,x,w) lm(as.formula(paste(y,"~",paste(x,w,sep="+"),"+",y,"_1ec",sep="")),data=temp.ldv),DVs,iv,fe.s)

#Year fixed effects, State Time Trends, and LDV
fe.s <- paste(c("election", paste(sort(unique(data$STATE)),"trend",sep="", collapse=" + ")), collapse=" + ")

out.ldv.2 <- Map(function(y,x,w) lm(as.formula(paste(y,"~",paste(x,w,sep="+"),"+",y,"_1ec",sep="")),data=temp.ldv),DVs,iv,fe.s)


#Combine list of results
models = list(out.fe.1, out.fe.2, out.ldv.1, out.ldv.2)


############
#Make Table#
############
#Make table
groups <- c(1:3)
coefs <- c(1,1,3)

Table.voteshare <- matrix(NA, ncol=4, nrow=2*length(groups) + sum(2*coefs))
digs <- 3


for (i in 1:length(models)){		
  out.temp <- models[[i]]
  column <- NULL
  for (dv in groups){
    est <- out.temp[[dv]]	
    if (i %in% 1:2){
      est.cl <- coeftest.cluster(temp.fe, est, cluster1="DISTRICT_ID_61")
    }			
    if (i %in% 3:4){
      est.cl <- coeftest.cluster(temp.ldv, est, cluster1="DISTRICT_ID_61")
    }
    
    if (dv %in% 1:2){
      #Format model estimates
      coef <- est.cl[2,1]
      se <- est.cl[2,2]
      N <- length(est$residuals)	
      R2 <- round(summary(est)$adj.r.squared,digs)
      
      toprint <- unlist(c(format(round(coef, digs), nsmall= digs), paste("(",format(round(se, digs), nsmall= digs),")",sep=""), N, R2))
      
      column <- c(column, toprint)
    }
    
    if (dv %in% 3){
      #Format model estimates
      index = nrow(est.cl)
      coef = as.vector(t(est.cl[c(2:3,index), 1:2]))
      coef = format(round(coef, digs), nsmall=digs, trim=T)
      coef[c(2,4,6)] = paste("(",coef[c(2,4,6)],")",sep="")
      N <- length(est$residuals)	
      R2 <- round(summary(est)$adj.r.squared,digs)
      toprint <- unlist(c(coef, N, R2))
      
      column <- c(column, toprint)
    }
    
  }
  
  Table.voteshare[,i] <- column
}	

#Export to LaTeX
################
model.specs = rbind(c("Yes", "Yes", "No", "No"), c("No", "No", "Yes", "Yes"), c("Yes", "Yes", "Yes", "Yes"), c("No", "Yes", "No", "Yes"))

Table.1  <- data.frame(rbind(Table.voteshare[1:8,], model.specs), stringsAsFactors=F)

names(Table.1) <- c("(1)","(2)","(3)","(4)")
rows = c("Riot Count$_{t-1}$","", "$N$", "$R^2$", "Riot Count$_{t-1}$","", "$N$", "$R^2$", "District fixed effects","Dependent Variable$_{t-1}$","Year fixed effects", "State time trends")

file.name = "./output/tables/Table1.tex"

if (make.latex.tables){
latex(Table.1,caption="Effect of riots on party district vote share", 
      label="table:riotpartyvs", ctable=T, title="", 
      rgroup=c("District INC Vote Share", "District BJS/BJP Vote Share", "Model Specifications"), 
      n.rgroup=c(4,4,4), cgroup=c("Fixed Effects", "Lagged DV"), n.cgroup=c(2,2),
      center='center', rowname=rows, col.just=c('c', 'c', 'c', 'c'), 
      insert.bottom="Standard errors clustered at the district level reported in parentheses. $N$ is across 307 districts.", 
      collabel.just=c('c','c','c','c'), file=file.name)
} else {print("TABLE 1"); print(Table.1)}
